notetools.make_notes_with_multiplied_durations
==============================================

.. autofunction:: abjad.tools.notetools.make_notes_with_multiplied_durations.make_notes_with_multiplied_durations
